==> manaplus_1.4.2.15.orig.tar.xz: manaplus-1.4.2.15/src/gui/windows/unregisterdialog.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2014  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef GUI_WINDOWS_UNREGISTERDIALOG_H
#define GUI_WINDOWS_UNREGISTERDIALOG_H

#include "gui/widgets/window.h"

#include <guichan/actionlistener.hpp>

class Button;
class LoginData;
class TextField;
class WrongDataNoticeListener;

/**
 * The Unregister dialog.
 *
 * \ingroup Interface
 */
class UnRegisterDialog final : public Window, public gcn::ActionListener
{
    public:
        /**
         * Constructor
         *
         * @see Window::Window
         */
        explicit UnRegisterDialog(LoginData *const loginData);

        A_DELETE_COPY(UnRegisterDialog)

        ~UnRegisterDialog();

        void postInit() override final;

        /**
         * Called when receiving actions from the widgets.
         */
        void action(const gcn::ActionEvent &event) override final;

    private:
        LoginData *mLoginData;

        TextField *mPasswordField;

        Button *mUnRegisterButton;
        Button *mCancelButton;

        WrongDataNoticeListener *mWrongDataNoticeListener;
};

#endif  // GUI_WINDOWS_UNREGISTERDIALOG_H

==> manaplus_1.4.3.1.1.orig.tar.xz: manaplus-1.4.3.1/src/gui/windows/unregisterdialog.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2014  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef GUI_WINDOWS_UNREGISTERDIALOG_H
#define GUI_WINDOWS_UNREGISTERDIALOG_H

#include "gui/widgets/window.h"

#include "listeners/actionlistener.h"

class Button;
class LoginData;
class TextField;
class WrongDataNoticeListener;

/**
 * The Unregister dialog.
 *
 * \ingroup Interface
 */
class UnRegisterDialog final : public Window,
                               public ActionListener
{
    public:
        /**
         * Constructor
         *
         * @see Window::Window
         */
        explicit UnRegisterDialog(LoginData *const loginData);

        A_DELETE_COPY(UnRegisterDialog)

        ~UnRegisterDialog();

        void postInit() override final;

        /**
         * Called when receiving actions from the widgets.
         */
        void action(const ActionEvent &event) override final;

    private:
        LoginData *mLoginData;

        TextField *mPasswordField;

        Button *mUnRegisterButton;
        Button *mCancelButton;

        WrongDataNoticeListener *mWrongDataNoticeListener;
};

#endif  // GUI_WINDOWS_UNREGISTERDIALOG_H
